Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the deployer v1 API group +kubebuilder:object:generate=true +groupName=deployer.aks
Index ¶
Constants ¶
const (
// AksAppKindStr is AksApp Kind
AksAppKindStr = "AksApp"
)
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "deployer.aks", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type AksApp ¶
type AksApp struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec AksAppSpec `json:"spec,omitempty"`
Status AksAppStatus `json:"status,omitempty"`
}
AksApp is the Schema for the aksapps API
func (*AksApp) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AksApp.
func (*AksApp) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AksApp) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AksAppList ¶
type AksAppList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AksApp `json:"items"`
}
AksAppList contains a list of AksApp
func (*AksAppList) DeepCopy ¶
func (in *AksAppList) DeepCopy() *AksAppList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AksAppList.
func (*AksAppList) DeepCopyInto ¶
func (in *AksAppList) DeepCopyInto(out *AksAppList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AksAppList) DeepCopyObject ¶
func (in *AksAppList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AksAppSpec ¶
type AksAppSpec struct {
Type string `json:"type"`
Version string `json:"version"`
Variables map[string]string `json:"variables"`
// TODO: Remove 'Credentials' and leave only 'Secrets'
// +optional
// +nullable
Credentials map[string]string `json:"credentials"`
// +optional
// +nullable
Secrets map[string]string `json:"secrets"`
// +optional
// +nullable
UnmanagedSecrets []string `json:"unmanagedSecrets"`
}
AksAppSpec defines the desired state of AksApp
func (*AksAppSpec) DeepCopy ¶
func (in *AksAppSpec) DeepCopy() *AksAppSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AksAppSpec.
func (*AksAppSpec) DeepCopyInto ¶
func (in *AksAppSpec) DeepCopyInto(out *AksAppSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AksAppStatus ¶
type AksAppStatus struct {
// Number of total replicas per AksApp
// +optional
Replicas int32 `json:"replicas,omitempty"`
// +optional
UnavailableReplicas int32 `json:"unavailableReplicas,omitempty"`
// Rollout version of AksApp
// +optional
RolloutVersion string `json:"rolloutVersion"`
// Rollout status of AksApp
// +optional
Rollout RolloutStatus `json:"rollout"`
// Reconciliation result of AksApp
// +optional
Reconciliation Reconciliation `json:"reconciliation,omitempty"`
// The list of all rollouts per AksApp
// +optional
Rollouts []Rollout `json:"rollouts,omitempty"`
}
AksAppStatus defines the observed state of AksApp
func (*AksAppStatus) DeepCopy ¶
func (in *AksAppStatus) DeepCopy() *AksAppStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AksAppStatus.
func (*AksAppStatus) DeepCopyInto ¶
func (in *AksAppStatus) DeepCopyInto(out *AksAppStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Reconciliation ¶
type Reconciliation struct {
// +nullable
// +optional
LastReconcileTime metav1.Time `json:"lastReconcileTime,omitempty"`
// +optional
Message string `json:"message,omitempty"`
// +optional
OperationID string `json:"operationId,omitempty"`
// +optional
Result ReconciliationResult `json:"result,omitempty"`
}
Reconciliation is the type for reconciliation
func (*Reconciliation) DeepCopy ¶
func (in *Reconciliation) DeepCopy() *Reconciliation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Reconciliation.
func (*Reconciliation) DeepCopyInto ¶
func (in *Reconciliation) DeepCopyInto(out *Reconciliation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReconciliationResult ¶
type ReconciliationResult string
ReconciliationResult is the type for reconciliation result
const ( ReconciliationSucceeded ReconciliationResult = "Succeeded" ReconciliationFailed ReconciliationResult = "Failed" )
These are the valid reconciliation results.
type Rollout ¶
type Rollout struct {
// +optional
Name string `json:"name"`
// +optional
Replicas int32 `json:"replicas,omitempty"`
UnavailableReplicas int32 `json:"unavailableReplicas,omitempty"`
// +optional
Rollout RolloutStatus `json:"rollout"`
}
Rollout is the type for rollout
func (*Rollout) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Rollout.
func (*Rollout) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RolloutStatus ¶
type RolloutStatus string
RolloutStatus is the type for rollout status
const ( RolloutCompleted RolloutStatus = "Completed" RolloutFailed RolloutStatus = "Failed" RolloutInProgress RolloutStatus = "InProgress" )
These are the valid rollout statuses.