datastructs

package
v0.0.0-...-a1c22f6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2021 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package datastructs contains commonly used data structs that don't naturally belong to any other packages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RedactedString

type RedactedString string

RedactedString represents a string whose Stringer implementation (String() func) always returns hard-coded <REDACTED> value instead of the actual string content. This is useful when you don't want the content to be accidentally written to log by %v or %+v, for example.

func (RedactedString) RealString

func (v RedactedString) RealString() string

Returns real string value

func (RedactedString) String

func (RedactedString) String() string

Returns hard-coded "<REDACTED>" value.

Jump to