mock_retry

package
v0.0.0-...-a1c22f6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package mock_retry is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockRetryerInterface

type MockRetryerInterface struct {
	// contains filtered or unexported fields
}

MockRetryerInterface is a mock of RetryerInterface interface

func NewMockRetryerInterface

func NewMockRetryerInterface(ctrl *gomock.Controller) *MockRetryerInterface

NewMockRetryerInterface creates a new mock instance

func (*MockRetryerInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockRetryerInterface) Run

func (m *MockRetryerInterface) Run(arg0 context.Context) (interface{}, error)

Run mocks base method

type MockRetryerInterfaceMockRecorder

type MockRetryerInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockRetryerInterfaceMockRecorder is the mock recorder for MockRetryerInterface

func (*MockRetryerInterfaceMockRecorder) Run

func (mr *MockRetryerInterfaceMockRecorder) Run(arg0 interface{}) *gomock.Call

Run indicates an expected call of Run

type MockSingleIterationInterface

type MockSingleIterationInterface struct {
	// contains filtered or unexported fields
}

MockSingleIterationInterface is a mock of SingleIterationInterface interface

func NewMockSingleIterationInterface

func NewMockSingleIterationInterface(ctrl *gomock.Controller) *MockSingleIterationInterface

NewMockSingleIterationInterface creates a new mock instance

func (*MockSingleIterationInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockSingleIterationInterface) RunOnce

func (m *MockSingleIterationInterface) RunOnce(arg0 context.Context) (retry.Status, interface{}, error)

RunOnce mocks base method

type MockSingleIterationInterfaceMockRecorder

type MockSingleIterationInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockSingleIterationInterfaceMockRecorder is the mock recorder for MockSingleIterationInterface

func (*MockSingleIterationInterfaceMockRecorder) RunOnce

func (mr *MockSingleIterationInterfaceMockRecorder) RunOnce(arg0 interface{}) *gomock.Call

RunOnce indicates an expected call of RunOnce

Jump to