Documentation
¶
Overview ¶
Package datastructs contains commonly used data structs that don't naturally belong to any other packages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RedactedString ¶
type RedactedString string
RedactedString represents a string whose Stringer implementation (String() func) always returns hard-coded <REDACTED> value instead of the actual string content. This is useful when you don't want the content to be accidentally written to log by %v or %+v, for example.
func (RedactedString) RealString ¶
func (v RedactedString) RealString() string
Returns real string value
func (RedactedString) String ¶
func (RedactedString) String() string
Returns hard-coded "<REDACTED>" value.
Click to show internal directories.
Click to hide internal directories.