Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CustomHTTPHandler ¶
type CustomHTTPHandler struct {
// contains filtered or unexported fields
}
CustomHTTPHandler implement http.Handler We need this custom handler to workaround a issue from ARM, where ARM send linked notification to us with // in url path. http library in golang redirect this kind of request to normalized path.
func NewCustomHTTPHandler ¶
func NewCustomHTTPHandler(handler http.Handler) *CustomHTTPHandler
NewCustomHTTPHandler create new CustomHTTPHandler a concrete http.Handler need here to process request, after the workaround.
func (*CustomHTTPHandler) ServeHTTP ¶
func (c *CustomHTTPHandler) ServeHTTP(httpwriter http.ResponseWriter, httpRequest *http.Request)
ServeHTTP implement http.Handler workaround the ARM issue, then process request.
type MetricEmitter ¶
type MetricEmitter interface {
ExpectedResult()
UnexpectedResult()
Heartbeat()
}
Click to show internal directories.
Click to hide internal directories.