Documentation
¶
Overview ¶
Package mock_retry is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockRetryerInterface ¶
type MockRetryerInterface struct {
// contains filtered or unexported fields
}
MockRetryerInterface is a mock of RetryerInterface interface
func NewMockRetryerInterface ¶
func NewMockRetryerInterface(ctrl *gomock.Controller) *MockRetryerInterface
NewMockRetryerInterface creates a new mock instance
func (*MockRetryerInterface) EXPECT ¶
func (m *MockRetryerInterface) EXPECT() *MockRetryerInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
type MockRetryerInterfaceMockRecorder ¶
type MockRetryerInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockRetryerInterfaceMockRecorder is the mock recorder for MockRetryerInterface
func (*MockRetryerInterfaceMockRecorder) Run ¶
func (mr *MockRetryerInterfaceMockRecorder) Run(arg0 interface{}) *gomock.Call
Run indicates an expected call of Run
type MockSingleIterationInterface ¶
type MockSingleIterationInterface struct {
// contains filtered or unexported fields
}
MockSingleIterationInterface is a mock of SingleIterationInterface interface
func NewMockSingleIterationInterface ¶
func NewMockSingleIterationInterface(ctrl *gomock.Controller) *MockSingleIterationInterface
NewMockSingleIterationInterface creates a new mock instance
func (*MockSingleIterationInterface) EXPECT ¶
func (m *MockSingleIterationInterface) EXPECT() *MockSingleIterationInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
type MockSingleIterationInterfaceMockRecorder ¶
type MockSingleIterationInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockSingleIterationInterfaceMockRecorder is the mock recorder for MockSingleIterationInterface
func (*MockSingleIterationInterfaceMockRecorder) RunOnce ¶
func (mr *MockSingleIterationInterfaceMockRecorder) RunOnce(arg0 interface{}) *gomock.Call
RunOnce indicates an expected call of RunOnce